# Chatbot Example
Example of a basic AGiXT chatbot.  Set your agent, make it to learn whichever urls or files, then just keep using that conversation ID to keep a conversation going with the AI where it is aware of the history of your conversation (last 5 interactions).  If you want to keep talking to it about the same docs with out the history, start a new conversation (generate a new UUID to use) and keep going with the same agent without any retraining of the documentation.

You can open this file in a Jupyter Notebook and run the code cells to see the example in action. https://github.com/Josh-XT/AGiXT/blob/main/examples/Chatbot.ipynb
